@@ -943,7 +943,7 @@ def relationship2dict(relationship: neo4j.data.Relationship):
 
 
 def parse_record(record: neo4j.data.Record, flag=True):
-    _record = {"node": [], "relationship": []}
+    _record = {"node": [], "relationship": [], "other": []}
     if isinstance(record, neo4j.data.Record):
         for rd in record:
             if isinstance(rd, neo4j.data.Node):
@@ -964,6 +964,11 @@ def parse_record(record: neo4j.data.Record, flag=True):
                         _record["relationship"].append(relationship2dict(x))
                     elif issubclass(x.__class__, neo4j.data.Relationship):
                         _record["relationship"].append(relationship2dict(x))
+                    else:
+                        _record["other"].append(rd)
+            else:
+                _record["other"].append(rd)
+
     if not flag:
         _record.pop("relationship")
     return _record
