@@ -129,25 +129,17 @@ class BaseHandler(RequestHandler):
                             params_list.append([parse_val(v, parameter_type) for v in argument_value])
                     else:
                         params_list.append(parse_val(argument_value, parameter_type))
-            try:
-                # 判断是否为异步非阻塞方法，true 则直接调用
-                if inspect.iscoroutinefunction(handler_method):
-                    data = await handler_method(*params_list)
-                else:
-                    # 阻塞方法异步调用
-                    data = await IOLoop.current().run_in_executor(None, handler_method, *params_list)
-                self.end_time = int(round(time.time() * 1000))
-                self.set_header("Api-Time", f"{self.end_time - self.start_time}ms")
-                if not self.original:
-                    self.write(json.dumps(ResponseResult(data=data), ensure_ascii=False, cls=JSONEncoder))
-            except Exception as e:
-                if hasattr(e, "status_code"):
-                    self.write(
-                        json.dumps(ResponseResult(data={"message": e.__str__()},
-                                                  status_code=e.status_code),
-                                   ensure_ascii=False, cls=JSONEncoder))
-                else:
-                    raise BusinessException(StatusCode.INTERNAL_SERVER_ERROR(e.__str__()))
+
+            # 判断是否为异步非阻塞方法，true 则直接调用
+            if inspect.iscoroutinefunction(handler_method):
+                data = await handler_method(*params_list)
+            else:
+                # 阻塞方法异步调用
+                data = await IOLoop.current().run_in_executor(None, handler_method, *params_list)
+            self.end_time = int(round(time.time() * 1000))
+            self.set_header("Api-Time", f"{self.end_time - self.start_time}ms")
+            if not self.original:
+                self.write(json.dumps(ResponseResult(data=data), ensure_ascii=False, cls=JSONEncoder))
         else:
             raise BusinessException(StatusCode.RESOURCE_NOT_FOUND)
 
@@ -186,7 +178,8 @@ class BaseHandler(RequestHandler):
         """
         error = kwargs["exc_info"]
         if isinstance(error[1], BusinessException):
-            self.write(json.dumps(ResponseResult(error[1].status_code), ensure_ascii=False))
+            self.set_status(200)
+            self.write(json.dumps(ResponseResult(status_code=error[1].status_code), ensure_ascii=False))
         else:
             # for line in traceback.format_exception(*kwargs["exc_info"]):
             #     self.write(line)
